// -----------------------------------------------------------------------
// PAD1616 Win 95 Software driver example        (c) Spectrum GmbH 08/1997
// -----------------------------------------------------------------------
// This example will only work correct, if the PAD1616 is installed with
// the default address and the smallest memory. Otherwise the example
// must be adapted.
// -----------------------------------------------------------------------

#include <stdio.h>
#include <string.h>
#include <windows.h>

#include "DLLTYP.H"
#include "SPECTRUM.H"
#include "ERRORS.H"
#include "REGS.H"

#define SAMPLES_PER_CHANNEL 1024
#define BYTES_PER_SAMPLE 2
#define CHANNELS 2

int PASCAL WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
	{
	int32 lStatus;
	ptr16 pnData;
	ptr16 pnDataCh0;
	ptr16 pnDataCh1;
	int16 nError;
	int   i;

	// ----- Alloc memory for test data ---------------------------------------
	pnData    = new int16[CHANNELS * SAMPLES_PER_CHANNEL * BYTES_PER_SAMPLE];
	pnDataCh0 = new int16[SAMPLES_PER_CHANNEL * BYTES_PER_SAMPLE];
	pnDataCh1 = new int16[SAMPLES_PER_CHANNEL * BYTES_PER_SAMPLE];

	// ----- Initialize Driver ------------------------------------------------
	SpcInitBoard (0, TYP_PAD1616a);								// PAD1616 100 kHz
	SpcSetParam (0, SPC_ISAADR,        0x340);	  			// base adress 0x340 (jumper)
	SpcSetParam (0, SPC_INSTMEM,       2097152l);			// 2M version

	// ----- Set params for Recording -----------------------------------------
	SpcSetParam (0, SPC_MEMSIZE,       SAMPLES_PER_CHANNEL);	// memsize per channel
	SpcSetParam (0, SPC_POSTTRIGGER,   SAMPLES_PER_CHANNEL/2);	// posttrigger = memsize/2
	SpcSetParam (0, SPC_SAMPLERATE,    50000l);			  		// samplerate 50 kHz
	SpcSetParam (0, SPC_TRIGGERMODE,   TM_CHXPOS);				// positive edge on marked channel
	SpcSetParam (0, SPC_TRIGGERLEVEL,  0);						// trigger level 0 = 0 V

	// ----- record channel 0 and 1, channel 0 is trigger channel -------------
	SpcSetParam (0, SPC_SEQUENCERESET, 0);										// Reset the channel sequence
	SpcSetParam (0, SPC_SEQUENCEADD,   SEQ_CH0 | SEQ_IR_1000MV | SEQ_TRIGGER);	// channel 0 with +/- 1V and trigger
	SpcSetParam (0, SPC_SEQUENCEADD,   SEQ_CH1 | SEQ_IR_2000MV);				// channel 1 with +/- 2V

	// ----- Start the board --------------------------------------------------
	nError = SpcSetParam (0, SPC_COMMAND,       SPC_START);

	// ----- Check for error --------------------------------------------------
	if (nError)
		{
		char  szErrorText[ERRORTEXTLEN], szMessageText[256];
		int32 lErrorCode, lErrorReg, lErrorValue;

		SpcGetParam (0, SPC_LASTERRORCODE, &lErrorCode);
		SpcGetParam (0, SPC_LASTERRORREG, &lErrorReg);
		SpcGetParam (0, SPC_LASTERRORVALUE, &lErrorValue);
		SpcGetParam (0, SPC_LASTERRORTEXT, (int32*) szErrorText);
		sprintf (szMessageText, "Code:\t%d\nReg.:\t%d\nValue:\t%d\nError:\t%s", lErrorCode, lErrorReg, lErrorValue, szErrorText);
		MessageBox (NULL, szMessageText, "Demo PAD1616 - driver error", MB_OK);

		return -1;
		}

	// ----- Wait for Status ready --------------------------------------------
	do
		{
		SpcGetParam (0, SPC_STATUS, &lStatus);
		}
	while (lStatus != SPC_READY);

	// ----- Read data (complete data of all channels) ------------------------
	SpcGetData (0, 0, 0, CHANNELS * SAMPLES_PER_CHANNEL, (dataptr) pnData);

	// ----- Divide data of channels from complete data -----------------------
	for (i=0; i < SAMPLES_PER_CHANNEL; i ++)
		{
		pnDataCh0[i] = pnData[i * CHANNELS + 0];
		pnDataCh1[i] = pnData[i * CHANNELS + 1];
		}

	MessageBox (0, "\nPAD1616 ready, Data transferred.\n", "Demo1616", MB_OK);

	// ----- Free data --------------------------------------------------------
	delete pnData;
	delete pnDataCh0;
	delete pnDataCh1 ;

	return 0;
	}
