// -----------------------------------------------------------------------
// PAD164  Win 3.1 Software driver example       (c) Spectrum GmbH 07/1998
// -----------------------------------------------------------------------
// This example will only work correct, if the PAD164  is installed with
// the default address and the smallest memory. Otherwise the example
// must be adapted.
// -----------------------------------------------------------------------

#include <stdio.h>
#include <windows.h>

#include "DLLTYP.H"
#include "SPECTRUM.H"
#include "ERRORS.H"
#include "REGS.H"

int16 Data0[1024l];

int PASCAL WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
  {
  int32 Status;

  // ----- Initialize Driver -----------------------------------------------
  SpcInitBoard (0, TYP_PAD164_2M);         // PAD164 2 MHz

  // ----- Set params for Recording ----------------------------------------
  SpcSetParam (0, SPC_ISAADR,              0x340);        // base address of board
  SpcSetParam (0, SPC_INSTMEM,             4194304l);     // 4M version
  SpcSetParam (0, SPC_READEPROM,           0l);           // Read adjustion values from EEPROM
  SpcSetParam (0, SPC_MEMSIZE,             1024l);        // memsize 1 kSample
  SpcSetParam (0, SPC_POSTTRIGGER,         512l);         // posttrigger 512 Sample
  SpcSetParam (0, SPC_SAMPLERATE,          1000000l);     // samplerate 1 MHz
  SpcSetParam (0, SPC_EXTERNALCLOCK,       0l);           // internal clock
  SpcSetParam (0, SPC_MULTI,               0l);           // no multiple recording
  SpcSetParam (0, SPC_MUX,                 0l);           // use channel 0
  SpcSetParam (0, SPC_AMP0,                AMP_BI1000);   // inputrange +/- 1000 mV
  SpcSetParam (0, SPC_TRIGGERMODE,         TM_SOFTWARE);  // software trigger
  SpcSetParam (0, SPC_TRIGGERLEVEL,        0l);           // not necessary for software trigger

  // ----- Start the board and test for driver error -----------------------
  if (SpcSetParam (0, SPC_COMMAND,         SPC_START) != ERR_OK)

	 // ----- read out error code -------------------------------------------
	 {
	 int32 ErrorCode, ErrorReg, ErrorValue;
	 char  ErrorText[ERRORTEXTLEN], s[255];
	 SpcGetParam (0, SPC_LASTERRORCODE,         &ErrorCode);
	 SpcGetParam (0, SPC_LASTERRORREG,          &ErrorReg);
	 SpcGetParam (0, SPC_LASTERRORVALUE,        &ErrorValue);
	 SpcGetParam (0, SPC_LASTERRORTEXT, (int32*) ErrorText);
	 sprintf (s, "Error:%ld register:%ld value:%ld\n%s", ErrorCode, ErrorReg, ErrorValue, ErrorText);
	 MessageBox (0, s, "Demo164", MB_OK);
	 return 0;
	 }

  // ----- Wait for Status ready -------------------------------------------
  do
	 {
	 SpcGetParam (0, SPC_STATUS, &Status);
	 }
  while (Status != SPC_READY);

  // ----- Read data -------------------------------------------------------
  SpcGetData (0, 0, 0, 1024l, (dataptr) &Data0[0]);

  MessageBox (0,"PAD164 ready, Data transferred.", "Demo164", MB_OK);
  return 0;
  }
