// -----------------------------------------------------------------------
// PCI.258 Win 3.x Software driver example        (c) Spectrum Gmbh 09/2000
// -----------------------------------------------------------------------
// This example will only work correct, if just one PCI.258 is installed
// in the system and no other Spectrum boards
// -----------------------------------------------------------------------

#include <stdio.h>
#include <string.h>
#include <windows.h>

#include "DLLTYP.H"
#include "SPECTRUM.H"
#include "ERRORS.H"
#include "REGS.H"

int PASCAL WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
	{
	int16 Count, PCIVersion, Error;
	int32 Typ, Version, Date, Status, IRCount, i, Range0, Range1;
	int8  Data0[1024l], Data1[1024l];
	char  c[1024], s[100];

	// ----- Initialisation of PCI Bus ---------------------------------------
	if (SpcInitPCIBoards (&Count, &PCIVersion) != ERR_OK) return 0;
	if (Count == 0) {MessageBox(NULL, "Count==0", "Test", MB_OK); return 0;}

	// ----- Test for PCI.258: 1.st board is board number 0 ------------------
	SpcGetParam (0, SPC_PCITYP, &Typ);
	if (Typ != TYP_PCI258)
		return 0;

	// ----- Get some PCI Parameters from driver and print them ---------------
	SpcGetParam (0, SPC_PCIVERSION,    &Version);
	SpcGetParam (0, SPC_PCIDATE,       &Date);
	sprintf (s, "\n\nPCI258   V %x.%x   produced %02d.%04d\n", (int16) ((Version>>8)&0x000000FF), (int16) (Version&0x000000FF), (int16) (Date&0x000000FF), (int16) (Date>>16));
	MessageBox (NULL, s, "Demo258", MB_OK);

	// ----- Read input ranges ------------------------------------------------
	SpcGetParam (0, SPC_READIRCOUNT,   &IRCount);
	sprintf (c, "\nInput Ranges PCI.258\n");
	for (i=0; i<IRCount; i++)
		{
		SpcGetParam (0, SPC_READRANGECH0_0+i,  &Range0);
		SpcGetParam (0, SPC_READRANGECH1_0+i,  &Range1);
		sprintf (s,"%ld: +/- %4ld mV    +/- %4ld mV\n", i, Range0, Range1);
		strcat (c,s);
		}
	MessageBox (NULL, c, "Demo258", MB_OK);

	// ----- Set Parameters for Recording -------------------------------------
	SpcSetParam (0, SPC_50OHM0,        0l);           // Channel 0 1 MOhm
	SpcSetParam (0, SPC_50OHM1,        0l);           // Channel 1 1 MOhm
	SpcSetParam (0, SPC_SAMPLERATE,    250000000l);   // Samplerate 200 MHz
	SpcSetParam (0, SPC_MEMSIZE,       1024l);        // Memsize 1 kSample
	SpcSetParam (0, SPC_POSTTRIGGER,   512l);         // Posttrigger 512 Sample
	SpcSetParam (0, SPC_EXTERNALCLOCK, 0);            // no external clock
	SpcSetParam (0, SPC_AMP0,          1000l);        // channel 0 +/- 1 V input range
	SpcSetParam (0, SPC_AMP1,          1000l);        // channel 1 +/- 1 V input range
	SpcSetParam (0, SPC_MULTI,         0);            // no multiple recording
	SpcSetParam (0, SPC_TRIGGERMODE,   TM_SOFTWARE);  // Software trigger
	SpcSetParam (0, SPC_TRIGGERLEVEL,  0l);           // No level for software trigger needed

	// ----- Start the board -------------------------------------------------
	Error = SpcSetParam (0, SPC_COMMAND,       SPC_START);

  // ----- Check for error -------------------------------------------------
  if (Error != ERR_OK)
	  {
	  int32 ErrorCode, ErrorReg, ErrorValue;

	  SpcGetParam (0, SPC_LASTERRORCODE, &ErrorCode);
	  SpcGetParam (0, SPC_LASTERRORREG, &ErrorReg);
	  SpcGetParam (0, SPC_LASTERRORVALUE, &ErrorValue);
	  sprintf (c, "Error:\n  Code:\t%ld\n  Reg.:\t%ld\n  Value:\t%ld\n", ErrorCode, ErrorReg, ErrorValue);
	  MessageBox (NULL, c, "Demo258 - error", MB_OK);
	  
	  return 0;
	  }

  // ----- Wait for Status ready -------------------------------------------

  do
	 {
	 SpcGetParam (0, SPC_STATUS, &Status);
	 }
  while (Status != SPC_READY);

  // ----- Read data -------------------------------------------------------
  SpcGetData (0, 0, 0, 1024l, (dataptr) &Data0[0]);
  SpcGetData (0, 1, 0, 1024l, (dataptr) &Data1[0]);

  MessageBox (NULL, "PCI.258 ready, data transferred\n", "Demo258", MB_OK);

  return 0;
  }
