// --------------------------------------------------------------------------
// PCI.412 Win95 Software driver example            (c) Spectrum GmbH 12/1998
// --------------------------------------------------------------------------
// This example will only work correct, if just one PCI.412 is installed in
// the system and no other Spectrum boards
// --------------------------------------------------------------------------

#include <stdio.h>
#include <string.h>
#include <windows.h>

#include "DLLTYP.H"
#include "SPECTRUM.H"
#include "ERRORS.H"
#include "REGS.H"

int16 Data0[1024l], Data1[1024l], Data2[1024l], Data3[1024l];

int PASCAL WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
  {
  int16 Count, PCIVersion;
  int32 Typ, Version, Date, Status, IRCount, i, Range0, Range1, Range2, Range3;
  int32 ErrorCode, ErrorReg, ErrorValue;
  char s[255], c[1024];

  // ----- Initialisation of PCI Bus ----------------------------------------
  if (SpcInitPCIBoards (&Count, &PCIVersion) != ERR_OK) return 0;
  if (Count == 0) return 0;

  // ----- Test for PCI.412: 1.st board is board number 0 -------------------
  SpcGetParam (0, SPC_PCITYP, &Typ);
  if (Typ != TYP_PCI412) return 0;

  // ----- Get some PCI Parameters from driver and print them ---------------
  SpcGetParam (0, SPC_PCIVERSION,    &Version);
  SpcGetParam (0, SPC_PCIDATE,       &Date);
  sprintf (s, "\n\nPCI.412   V %x.%x   produced %02d.%04d\n",
          (int16) ((Version>>8)&0x000000FF), (int16) (Version&0x000000FF),
          (int16) (Date&0x000000FF), (int16) (Date>>16));
  MessageBox (NULL, s, "Demo412", MB_OK);

  // ----- Read input ranges ------------------------------------------------
  SpcGetParam (0, SPC_READIRCOUNT,   &IRCount);
  sprintf (c, "\nInput Ranges PCI.412\n    Channel 0     Channel 1     Channel 2     Channel 3\n");
  for (i=0; i<IRCount; i++)
   {
   SpcGetParam (0, SPC_READRANGECH0_0+i,  &Range0);
   SpcGetParam (0, SPC_READRANGECH1_0+i,  &Range1);
   SpcGetParam (0, SPC_READRANGECH2_0+i,  &Range2);
   SpcGetParam (0, SPC_READRANGECH3_0+i,  &Range3);
   sprintf (s, "%ld: +/- %4ld mV   +/- %4ld mV   +/- %4ld mV   +/- %4ld mV\n",
               i, Range0, Range1, Range2, Range3);
   strcat (c,s);
	 }
  MessageBox (NULL, c, "Demo412", MB_OK);

  // ----- Set Parameters for Recording -------------------------------------
  SpcSetParam (0, SPC_COMMAND,       SPC_NOSYNC);  // No Synchronisation
  SpcSetParam (0, SPC_SAMPLERATE,    10000000l);   // Samplerate 10 MHz
  SpcSetParam (0, SPC_MEMSIZE,       1024l);       // Memsize 1 kSample
  SpcSetParam (0, SPC_POSTTRIGGER,   512l);        // Posttrigger 512 Sample
  SpcSetParam (0, SPC_EXTERNALCLOCK, 0);           // no external clock
  SpcSetParam (0, SPC_TRIGGEROUT,    0);           // no trigger output
  SpcSetParam (0, SPC_EXTERNOUT,     0);           // no clock output
  SpcSetParam (0, SPC_PATTERNENABLE, 0);           // no pattern input
  SpcSetParam (0, SPC_AMP0,          1000l);       // ch. 0 +/- 1 V input range
  SpcSetParam (0, SPC_AMP1,          1000l);       // ch. 1 +/- 1 V input range
  SpcSetParam (0, SPC_AMP2,          1000l);       // ch. 2 +/- 1 V input range
  SpcSetParam (0, SPC_AMP3,          1000l);       // ch. 3 +/- 1 V input range
  SpcSetParam (0, SPC_TRIGGERMODE,   TM_SOFTWARE); // Software trigger
  
  /*
  // ----- Set Trigger: (Ch0 0mV pos edge) OR (Ch1 0mV neg edge) --------------
  SpcSetParam (0, SPC_TRIGGERMODE,   TM_CHOR);     // OR trigger
  SpcSetParam (0, SPC_TRIGGERMODE0,  TM_CH0POS);   // Ch0 pos. edge
  SpcSetParam (0, SPC_TRIGGERLEVEL0, 0l);          // Ch0 0mV triggerlevel
  SpcSetParam (0, SPC_TRIGGERMODE1,  TM_CH1OFF);   // Ch1 neg. edge
  SpcSetParam (0, SPC_TRIGGERLEVEL1, 0l);          // Ch1 0mV triggerlevel
  SpcSetParam (0, SPC_TRIGGERMODE2,  TM_CH2OFF);   // Ch2 not used for trigger
  SpcSetParam (0, SPC_TRIGGERMODE3,  TM_CH3OFF);   // Ch3 not used for trigger
  */
    
  // ----- Start the board --------------------------------------------------
  if (SpcSetParam (0, SPC_COMMAND,       SPC_START) != ERR_OK)
 
  // ----- parameter error --------------------------------------------------
    {
    SpcGetParam (0, SPC_LASTERRORCODE,  &ErrorCode);
    SpcGetParam (0, SPC_LASTERRORREG,   &ErrorReg);
    SpcGetParam (0, SPC_LASTERRORVALUE, &ErrorValue);
    sprintf (s, "Error:%ld in Register: %ld, Value: %ld", ErrorCode, ErrorReg, ErrorValue);
    MessageBox (NULL, s, "Demo412-Error", MB_OK);
    return 0;
    }

  // ----- Wait for Status ready --------------------------------------------
  do
   {
   SpcGetParam (0, SPC_STATUS, &Status);
   }
  while (Status != SPC_READY);

  // ----- Read data --------------------------------------------------------
  SpcGetData (0, 0, 0, 1024l, (dataptr) &Data0[0]);
  SpcGetData (0, 1, 0, 1024l, (dataptr) &Data1[0]);
  SpcGetData (0, 2, 0, 1024l, (dataptr) &Data2[0]);
  SpcGetData (0, 3, 0, 1024l, (dataptr) &Data3[0]);

  MessageBox (NULL, "PCI.412 ready, Data transferred", "Demo412", MB_OK);

  return 0;
  }
