// -----------------------------------------------------------------------
// PCI.DIO32 software driver example        (c) Spectrum Gmbh 11/1999
// -----------------------------------------------------------------------
// This example will only work correct, if just one PCI.DIO32 is installed
// in the system and no other Spectrum boards
// -----------------------------------------------------------------------

#include <stdio.h>

#include "DLLTYP.H"
#include "SPECTRUM.H"
#include "ERRORS.H"
#include "REGS.H"

main()
  {
  int16 Count, PCIVersion;
  int32 Typ, Version, Date, Status;
  int16 data0[1024l], data1[1024l];

  // ----- Initialisation of PCI Bus ---------------------------------------
  if (SpcInitPCIBoards (&Count, &PCIVersion) != ERR_OK) return 0;
  if (Count == 0) return 0;

  // ----- Test for PCI.DIO32: 1.st board is board number 0 ------------------
  SpcGetParam (0, SPC_PCITYP, &Typ);
  if (Typ != TYP_PCIDIO32) return 0;

  // ----- Get some PCI Parameters from driver and print them ---------------
  SpcGetParam (0, SPC_PCIVERSION,    &Version);
  SpcGetParam (0, SPC_PCIDATE,       &Date);
  printf ("PCI.DIO32   V %x.%x   produced %02d.%04d\n", (int16) ((Version>>8)&0x000000FF),         
         (int16) (Version&0x000000FF), (int16) (Date&0x000000FF), (int16) (Date>>16));

  // ----- Set Parameters for Recording -------------------------------------
  SpcSetParam (0, SPC_SAMPLERATE,    100000000l);   // samplerate 100 MHz
  SpcSetParam (0, SPC_MEMSIZE,       1024l);        // memsize 1 kSample
  SpcSetParam (0, SPC_SINGLESHOT,    0);            // normal operation
  SpcSetParam (0, SPC_POSTTRIGGER,   512l);         // posttrigger 512 Sample
  SpcSetParam (0, SPC_EXTERNALCLOCK, 0);            // no external clock
  SpcSetParam (0, SPC_EXTERNOUT,     0);            // no clock and trigger output
  SpcSetParam (0, SPC_TRIGGERMODE,   TM_SOFTWARE);  // software trigger
  SpcSetParam (0, SPC_TRIGGERPATTERN,0xffffffffl);  // no triggerpattern
  SpcSetParam (0, SPC_TRIGGERMASK,   0xffffffffl);  // no triggerpattern
  SpcSetParam (0, SPC_PULSEWIDTH,    1l);           // tirggerwitdh one sample
  SpcSetParam (0, SPC_TRIGGEREDGE,   TE_POS);       // raising triggeredge
  SpcSetParam (0, SPC_MULTI,         0l);           // no multiple recording
  SpcSetParam (0, SPC_INOUT0,        0l);           // channel 0 input
  SpcSetParam (0, SPC_INOUT1,        1l);           // channel 1 output
  SpcSetParam (0, SPC_110OHM0,       1l);           // channel 0 110 Ohm input impedance
  SpcSetParam (0, SPC_110OHM1,       0l);           // channel 1 high input impedance

  // ----- calculate and set output data -----------------------------------
  for (int i = 0; i < 1024; i++)
    data1[i] = i;
  SpcSetData (0, 1, 0, 1024l, (dataptr) data1);     // write data after the channel direction is set

  // ----- start the board -------------------------------------------------
  SpcSetParam (0, SPC_COMMAND,       SPC_START);

  // ----- wait for status ready -------------------------------------------
  do
    {
    SpcGetParam (0, SPC_STATUS, &Status);
    }
  while (Status != SPC_READY);

  // ----- read data -------------------------------------------------------
  SpcGetData (0, 0, 0, 1024l, (dataptr) data0);

  return 0;
  }
